# Copyright (C) 2021-2023 MicroSys Electronics GmbH
# Author: Kay Potthoff <kay.potthoff@microsys.de>

inherit microsys

FILESEXTRAPATHS:prepend := "${THISDIR}/${PN}:"
PATCHTOOL = "git"
PATCH_COMMIT_FUNCTIONS = "1"

#URL    = "git://github.com/MicroSysElectronics/arm-trusted-firmware;protocol=https"
#BRANCH = "microsys-s32-bsp34.0"
#SRCREV = "b8b42a323fcda6410179eef52cfb475025263194"

BRANCH = "release/bsp36.0-2.5"
SRCREV = "6bbd669a317fdc1965f83c3f0b9b3acff2ffc21b"
SRC_URI:append = " file://atf.patch"

PROVIDES += "virtual/arm-trusted-firmware"

inherit deploy

PACKAGE_ARCH ??= "${MACHINE_ARCH}"

do_compile[depends] = "u-boot-s32:do_install"
do_compile[deptask] += "u-boot-s32:do_patch"

BUILD_MESSAGE_TIMESTAMP = "${@microsys_get_iso_datetime_str(d)}"

python do_patch:prepend() {
    if d.getVar('PATCHTOOL') == 'git':
        srcsubdir = d.getVar('S')
        bb.process.run('git config am.threeWay true', cwd=srcsubdir)
        bb.process.run('git config am.keepcr true', cwd=srcsubdir)
        bb.process.run('git config apply.whitespace fix', cwd=srcsubdir)
        bb.process.run('git config apply.ignoreWhitespace change', cwd=srcsubdir)
}

PLATFORM ?= "${MACHINE}"
ATF_PLAT ?= "${MACHINE}"

COMPATIBLE_MACHINE .= "|(mpxs32g)"

# The package is empty which leads to problems when
# building the image with devtool. This fix lets devtool
# build the image with modified arm-trusted-firmware.
#ALLOW_EMPTY_${PN} = "1"

# Set log-level:
#       0  (LOG_LEVEL_NONE)
#       10 (LOG_LEVEL_ERROR)
#       20 (LOG_LEVEL_NOTICE)
#       30 (LOG_LEVEL_WARNING)
#       40 (LOG_LEVEL_INFO)
#       50 (LOG_LEVEL_VERBOSE)
# Default is LOG_LEVEL_INFO (40):
#EXTRA_OEMAKE += "LOG_LEVEL=40"

# Uncomment these lines for more debugging:
#BUILD_TYPE = "debug"
#EXTRA_OEMAKE += "S32G_USE_LINFLEX_IN_BL31=1 DEBUG=1"

do_compile:prepend() {

    if [ -f ${S}/localversion-microsys ]; then
        BUILD_STRING=`cat ${S}/localversion-microsys`
    else
        BUILD_STRING=${DISTRO_VERSION}
    fi

    export BUILD_MESSAGE_TIMESTAMP="\"${BUILD_MESSAGE_TIMESTAMP}\""
    export BUILD_STRING="${BUILD_STRING}"
}

do_install:append() {
    install -m 0755 -o root -g root -d ${D}/boot
    install -m 0644 -o root -g root ${ATF_BINARIES}/${ATF_FLASH_IMAGE_FILE} ${D}/boot
}

FILES:${PN} += "/boot"
