# Copyright (C) 2020-2023 MicroSys Electronics GmbH
# Author: Kay Potthoff <kay.potthoff@microsys.de>

inherit microsys

FILESEXTRAPATHS:prepend := "${THISDIR}/${PN}:"
PATCHTOOL = "git"
PATCH_COMMIT_FUNCTIONS = "1"

NXP_FIRMWARE_LOCAL_DIR:s32g2 := "${THISDIR}/${PN}/s32g2"
NXP_FIRMWARE_LOCAL_DIR:s32g3 := "${THISDIR}/${PN}/s32g2"

LIC_FILES_CHKSUM += "file://PFE-License.txt;md5=3efaacbb2298460a2345c5950a9ebb6a"

COMPATIBLE_MACHINE:append = "|mpxs32g"

do_compile[depends] += "virtual/kernel:do_deploy"

URL:append = ";branch=master"
SRCREV = "9b1c721d40763b92e9010fc9567635f130ee5bc9"

SRC_URI := "${@microsys_var_rm(d, 'SRC_URI', '.*\\bNXP_FIRMWARE_LOCAL_DIR\\b.*')}"

SRC_URI += "file://0001-sw-linux-phylink-fixed-SGMII-AN-feature.patch;name=patch0001"
SRC_URI += "file://0002-sw-linux-pfeng-pfeng-drv.c-fixed-pfeng_drv_shutdown.patch;name=patch0002"
SRC_URI += "file://0003-sw-linux-pfeng-mdio.c-fixed-return-codes.patch;name=patch0003"
SRC_URI += "file://0004-sw-linux-pfeng-pfeng-drv.c-fixes-sporadic-kernel-cra.patch;name=patch0004"
SRC_URI += "file://0006-hw-s32g-pfe_tmu_csr.c-no-TMU-for-S32G2.patch;name=patch0006"

SRC_URI[patch0001.md5sum] = "44dd92aa92dc3bb6b25ee6174e1ee3dc"
SRC_URI[patch0002.md5sum] = "0b5df19bf31757d488f577e4eda1500c"
SRC_URI[patch0003.md5sum] = "b3e4c02641eb5303d553dcd6ccbb2c2a"
SRC_URI[patch0004.md5sum] = "d12215877da22ac55510e30437f5c95a"
SRC_URI[patch0006.md5sum] = "3cccb1b4c475c864a91c4d7f77e24227"

python do_patch:prepend() {
    if d.getVar('PATCHTOOL') == 'git':
        srcsubdir = d.getVar('S')
        bb.process.run('git config am.threeWay true', cwd=srcsubdir)
        bb.process.run('git config am.keepcr true', cwd=srcsubdir)
        bb.process.run('git config apply.whitespace fix', cwd=srcsubdir)
        bb.process.run('git config apply.ignoreWhitespace no', cwd=srcsubdir)
}

do_patch:append() {
    import shutil

    shutil.copy2(os.path.join(d.getVar("NXP_FIRMWARE_LOCAL_DIR"),
                              "PFE-License.txt"),
                 os.path.join(d.getVar("S"), "PFE-License.txt"))

    class_name = os.path.join(d.getVar("S"), d.getVar("FW_INSTALL_CLASS_NAME"))
    util_name = os.path.join(d.getVar("S"), d.getVar("FW_INSTALL_UTIL_NAME"))

    shutil.copy2(os.path.join(d.getVar("NXP_FIRMWARE_LOCAL_DIR"),
                              d.getVar("PFE_FW_CLASS_BIN")),
                 class_name)

    shutil.copy2(os.path.join(d.getVar("NXP_FIRMWARE_LOCAL_DIR"),
                              d.getVar("PFE_FW_UTIL_BIN")),
                 util_name)

    os.chmod(class_name, 0o0644)
    os.chmod(util_name, 0o0644)
}

module_do_install() {
    mkdir -p ${INSTALL_DIR}
    install -D "${MDIR}/pfeng.ko" "${INSTALL_DIR}/pfeng.ko"
    mkdir -p "${FW_INSTALL_DIR}"
    install -D -m 0644 "${NXP_FIRMWARE_LOCAL_DIR}/${PFE_FW_CLASS_BIN}" "${FW_INSTALL_DIR}/${FW_INSTALL_CLASS_NAME}"
    install -D -m 0644 "${NXP_FIRMWARE_LOCAL_DIR}/${PFE_FW_UTIL_BIN}" "${FW_INSTALL_DIR}/${FW_INSTALL_UTIL_NAME}"
    install -D -m 0644 "${NXP_FIRMWARE_LOCAL_DIR}/${PFE_FW_CLASS_BIN}" "${D}/${FW_INSTALL_CLASS_NAME}"
    install -D -m 0644 "${NXP_FIRMWARE_LOCAL_DIR}/${PFE_FW_UTIL_BIN}" "${D}/${FW_INSTALL_UTIL_NAME}"
}

FILES:${PN} += "/${FW_INSTALL_CLASS_NAME} /${FW_INSTALL_UTIL_NAME}"

# This is a workaround for the build error
# "basehash value changed"
do_populate_sysroot[vardepsexclude] += "PROVIDES"
do_populate_setscene[vardepsexclude] += "PROVIDES"
do_package[vardepsexclude] += "PROVIDES RPROVIDES_${PN}"
